==> react-native-web-jsonschema-form-2.2.4.tgz: package/widgets/TagInputWidget.js <==
import _isFunction from "lodash/isFunction";
import _pick from "lodash/pick";
import _noop from "lodash/noop";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import RNTagInput from 'react-native-web-ui-components/TagInput';
import { useOnChange, useAutoFocus } from '../utils';
const styles = StyleSheet.create({
  defaults: {
    marginBottom: 10
  },
  fullWidth: {
    width: '100%'
  },
  auto: {
    marginBottom: 0
  }
});
const allowedAttributes = ['hasError', 'value', 'readonly', 'disabled', 'secureTextEntry', 'placeholder', 'keyboardType', 'multiline', 'numberOfLines', 'items', 'isMatch', 'text', 'tagStyle', 'inputStyle', 'menuStyle', 'itemStyle', 'allowNew', 'Item', 'Menu', 'Tag', 'Input'];

const parseValue = (type, text) => {
  if (type === 'number' || type === 'integer') {
    return parseFloat(text);
  }

  return text;
};

const useBuildNew = ({
  schema,
  buildNew
}) => text => {
  if (_isFunction(buildNew)) {
    return buildNew(text);
  }

  if (schema.items.type === 'object') {
    const [attribute] = Object.keys(schema.items.properties);
    const {
      type
    } = schema.items.properties[attribute];
    return {
      [attribute]: parseValue(type, text)
    };
  }

  return parseValue(schema.items.type, text);
};

const useGetItemValue = ({
  schema,
  getItemValue
}) => item => {
  if (_isFunction(getItemValue)) {
    return getItemValue(item);
  }

  if (schema.items.type === 'object') {
    const [attribute] = Object.keys(schema.items.properties);
    return item[attribute];
  }

  return item;
};

const TagInputWidget = props => {
  const {
    auto,
    name,
    style,
    schema,
    uiSchema,
    ...nextProps
  } = props;
  const autoFocusParams = useAutoFocus(props);
  const onChange = useOnChange(props);
  const buildNew = useBuildNew(props);
  const getItemValue = useGetItemValue(props);

  if (schema.type !== 'array') {
    throw new Error('TagInputWidget can only be used with arrays.');
  }

  const currentStyle = [styles.defaults, auto ? styles.auto : styles.fullWidth, style];
  return /*#__PURE__*/React.createElement(RNTagInput, _extends({}, _pick(nextProps, allowedAttributes), autoFocusParams, {
    autoCapitalize: "none",
    className: "TagInput__widget",
    style: currentStyle,
    onSubmitEditing: _noop,
    name: name,
    onChange: onChange,
    buildNew: buildNew,
    getItemValue: getItemValue
  }));
};

TagInputWidget.hideable = false;
TagInputWidget.propTypes = {
  name: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  schema: PropTypes.shape().isRequired,
  uiSchema: PropTypes.shape().isRequired,
  buildNew: PropTypes.func,
  style: StylePropType,
  auto: PropTypes.bool
};
TagInputWidget.defaultProps = {
  buildNew: null,
  style: null,
  auto: false
};
export default TagInputWidget;

==> react-native-web-jsonschema-form-3.2.2.tgz: package/widgets/TagInputWidget.js <==
import _isFunction from "lodash/isFunction";
import _pick from "lodash/pick";
import _noop from "lodash/noop";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import RNTagInput from 'react-native-web-ui-components/TagInput';
import { useOnChange, useAutoFocus } from '../utils';
const styles = StyleSheet.create({
  defaults: {
    marginBottom: 10
  },
  fullWidth: {
    width: '100%'
  },
  auto: {
    marginBottom: 0
  }
});
const allowedAttributes = ['hasError', 'value', 'readonly', 'disabled', 'secureTextEntry', 'placeholder', 'keyboardType', 'multiline', 'numberOfLines', 'items', 'getItemValue', 'isMatch', 'Item', 'itemHeight', 'itemProps', 'itemStyle', 'Input', 'inputStyle', 'Tag', 'tagStyle', 'Menu', 'menuStyle', 'menuVisibleWhenFocused', 'Spinner', 'spinnerHeight', 'EmptyResult', 'emptyResultHeight', 'throttleDelay', 'debounceDelay', 'throttleDebounceThreshold', 'allowNew', 'text'];

const parseValue = (type, text) => {
  if (type === 'number' || type === 'integer') {
    return parseFloat(text);
  }

  return text;
};

const useBuildNew = ({
  schema,
  buildNew
}) => text => {
  if (_isFunction(buildNew)) {
    return buildNew(text);
  }

  if (schema.items.type === 'object') {
    const [attribute] = Object.keys(schema.items.properties);
    const {
      type
    } = schema.items.properties[attribute];
    return {
      [attribute]: parseValue(type, text)
    };
  }

  return parseValue(schema.items.type, text);
};

const useGetItemValue = ({
  schema,
  getItemValue
}) => item => {
  if (_isFunction(getItemValue)) {
    return getItemValue(item);
  }

  if (schema.items.type === 'object') {
    const [attribute] = Object.keys(schema.items.properties);
    return item[attribute];
  }

  return item;
};

const TagInputWidget = props => {
  const {
    auto,
    name,
    style,
    schema,
    uiSchema,
    ...nextProps
  } = props;
  const autoFocusParams = useAutoFocus(props);
  const onChange = useOnChange(props);
  const buildNew = useBuildNew(props);
  const getItemValue = useGetItemValue(props);

  if (schema.type !== 'array') {
    throw new Error('TagInputWidget can only be used with arrays.');
  }

  const currentStyle = [styles.defaults, auto ? styles.auto : styles.fullWidth, style];
  return /*#__PURE__*/React.createElement(RNTagInput, _extends({}, _pick(nextProps, allowedAttributes), autoFocusParams, {
    autoCapitalize: "none",
    className: "TagInput__widget",
    style: currentStyle,
    onSubmitEditing: _noop,
    name: name,
    onChange: onChange,
    buildNew: buildNew,
    getItemValue: getItemValue
  }));
};

TagInputWidget.hideable = false;
TagInputWidget.propTypes = {
  name: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  schema: PropTypes.shape().isRequired,
  uiSchema: PropTypes.shape().isRequired,
  buildNew: PropTypes.func,
  style: StylePropType,
  auto: PropTypes.bool
};
TagInputWidget.defaultProps = {
  buildNew: null,
  style: null,
  auto: false
};
export default TagInputWidget;
